@@ -22,8 +22,8 @@ class generatedClass(ZIDS_Pipeline):
     def build_pipeline(self):
         self.preprocessor = generatedProjectNamePreprocess(artifacts=self.artifacts)
         self.postprocessor = generatedProjectNamePostprocess(artifacts=self.artifacts)
-        self.predictor = generatedProjectNamePredictor(artifacts=self.artifacts)
-        self.forcer = generatedProjectNameForcer(artifacts=self.artifacts)
+        self.predictor = generatedProjectNamePredictor()
+        self.forcer = generatedProjectNameForcer()
         self.add_component(self.predictor)
         self.add_component(self.forcer)
 
